==> kumactl-2.4.2.tar.gz: kuma-2.4.2/pkg/mads/v1/generator/assignments.go <==
package generator

import (
	"github.com/kumahq/kuma/api/mesh/v1alpha1"
	observability_v1 "github.com/kumahq/kuma/api/observability/v1"
	"github.com/kumahq/kuma/pkg/core"
	core_xds "github.com/kumahq/kuma/pkg/core/xds"
	"github.com/kumahq/kuma/pkg/mads"
	"github.com/kumahq/kuma/pkg/mads/generator"
)

var log = core.Log.WithName("mads").WithName("v1").WithName("generator")

// MonitoringAssignmentsGenerator knows how to generate MonitoringAssignment
// resources for a given set of Dataplanes.
type MonitoringAssignmentsGenerator struct{}

// Generate implements mads.ResourceGenerator
func (g MonitoringAssignmentsGenerator) Generate(args generator.Args) ([]*core_xds.Resource, error) {
	meshIndex := mads.IndexMeshes(args.Meshes)

	resources := make([]*core_xds.Resource, 0, len(args.Dataplanes))
	for _, dataplane := range args.Dataplanes {
		mesh, exist := meshIndex[dataplane.Meta.GetMesh()]
		if !exist {
			// might be the case when the entire mesh is in the process of being deleted
			continue
		}

		prometheusEndpoint, err := dataplane.GetPrometheusConfig(mesh)
		if err != nil {
			log.Info("could not get prometheus endpoint from the dataplane", err)
			// does not return error to not break MADS for other dataplanes
			continue
		}

		if prometheusEndpoint == nil {
			// Prometheus metrics are not enabled on that Mesh
			continue
		}

		schema := "http"
		if prometheusEndpoint.GetTls() != nil && prometheusEndpoint.Tls.GetMode() == v1alpha1.PrometheusTlsConfig_providedTLS {
			schema = "https"
		}

		// TODO: could also group by service, and have one assignment per service
		assignment := &observability_v1.MonitoringAssignment{
			Mesh:    dataplane.Meta.GetMesh(),
			Service: dataplane.Spec.GetIdentifyingService(),
			Targets: []*observability_v1.MonitoringAssignment_Target{{
				Scheme:      schema,
				Name:        dataplane.GetMeta().GetName(),
				Address:     mads.Address(dataplane, prometheusEndpoint),
				MetricsPath: prometheusEndpoint.GetPath(),
				Labels:      mads.DataplaneLabels(dataplane, args.MeshGateways),
			}},
		}

		resources = append(resources, &core_xds.Resource{
			Name:     mads.DataplaneAssignmentName(dataplane),
			Resource: assignment,
		})
	}

	return resources, nil
}

==> kumactl-2.9.3.tar.gz: kuma-2.9.3/pkg/mads/v1/generator/assignments.go <==
package generator

import (
	"github.com/kumahq/kuma/api/mesh/v1alpha1"
	observability_v1 "github.com/kumahq/kuma/api/observability/v1"
	"github.com/kumahq/kuma/pkg/core"
	core_xds "github.com/kumahq/kuma/pkg/core/xds"
	"github.com/kumahq/kuma/pkg/mads"
	"github.com/kumahq/kuma/pkg/mads/generator"
)

var log = core.Log.WithName("mads").WithName("v1").WithName("generator")

// MonitoringAssignmentsGenerator knows how to generate MonitoringAssignment
// resources for a given set of Dataplanes.
type MonitoringAssignmentsGenerator struct{}

// Generate implements mads.ResourceGenerator
func (g MonitoringAssignmentsGenerator) Generate(args generator.Args) ([]*core_xds.Resource, error) {
	meshIndex := mads.IndexMeshes(args.Meshes)

	resources := make([]*core_xds.Resource, 0, len(args.Dataplanes))
	for _, dataplane := range args.Dataplanes {
		mesh, exist := meshIndex[dataplane.Meta.GetMesh()]
		if !exist {
			// might be the case when the entire mesh is in the process of being deleted
			continue
		}

		prometheusEndpoint, err := dataplane.GetPrometheusConfig(mesh)
		if err != nil {
			log.Info("could not get prometheus endpoint from the dataplane", "cause", err)
			// does not return error to not break MADS for other dataplanes
			continue
		}

		if prometheusEndpoint == nil {
			// Prometheus metrics are not enabled on that Mesh
			continue
		}

		schema := "http"
		if prometheusEndpoint.GetTls() != nil && prometheusEndpoint.Tls.GetMode() == v1alpha1.PrometheusTlsConfig_providedTLS {
			schema = "https"
		}

		// TODO: could also group by service, and have one assignment per service
		assignment := &observability_v1.MonitoringAssignment{
			Mesh:    dataplane.Meta.GetMesh(),
			Service: dataplane.Spec.GetIdentifyingService(),
			Targets: []*observability_v1.MonitoringAssignment_Target{{
				Scheme:      schema,
				Name:        dataplane.GetMeta().GetName(),
				Address:     mads.Address(dataplane, prometheusEndpoint),
				MetricsPath: prometheusEndpoint.GetPath(),
				Labels:      mads.DataplaneLabels(dataplane, args.MeshGateways),
			}},
		}

		resources = append(resources, &core_xds.Resource{
			Name:     mads.DataplaneAssignmentName(dataplane),
			Resource: assignment,
		})
	}

	return resources, nil
}
